cis_config: comm_head_t Struct Reference

cis_config

Public Attributes | List of all members
comm_head_t Struct Reference

Header information passed by comms for multipart messages. More...

`#include <comm_header.h>`

## Public Attributes
size_t | size
| Size of incoming message.
char | address [COMMBUFFSIZ]
| Address that message will comm in on.
int | multipart
| 1 if message is multipart, 0 if it is not.
size_t | bodysiz
| Size of body.
size_t | bodybeg
| Start of body in header.
int | valid
| 1 if the header is valid, 0 otherwise.
char | id [COMMBUFFSIZ]
| Unique ID associated with this message.
char | response_address [COMMBUFFSIZ]
| Response address.
char | request_id [COMMBUFFSIZ]
| Request id.
int | serializer_type
| Code indicating the type of serializer.
char | format_str [COMMBUFFSIZ]
| Format string for serializer.
char | field_names [COMMBUFFSIZ]
| String containing field names.
char | field_units [COMMBUFFSIZ]
| String containing field units.
int | as_array
| 1 if messages will be serialized arrays.
char | zmq_reply [COMMBUFFSIZ]
| Reply address for ZMQ sockets.
char | zmq_reply_worker [COMMBUFFSIZ]
| Reply address for worker socket.

## Detailed Description

Header information passed by comms for multipart messages.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/communication/comm_header.h